@@ -43,7 +43,10 @@ MainWidget::MainWidget(QWidget *parent) :
     // table
     m_layout.addWidget(&m_statuslbl);
     m_layout.addWidget(m_scoretbl);
+    m_layout.setSizeConstraint(QLayout::SetFixedSize);
     this->setLayout(&m_layout);
+    this->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
+
     m_statuslbl.show();
 
     connect(m_settingsdlg, SIGNAL(accepted()),
